# textual-enhanced ChangeLog

## v0.3.0

**Released: 2025-02-03**

- Added `Confirm`. ([#8](https://github.com/davep/textual-enhanced/pull/8))
- Added `add_key`. ([#9](https://github.com/davep/textual-enhanced/pull/9))

## v0.2.0

**Released: 2025-02-02**

- Added `ModalInput`.
  ([#3](https://github.com/davep/textual-enhanced/pull/3))
- Added `HelpScreen`.
  ([#5](https://github.com/davep/textual-enhanced/pull/5))
- Added common command messages and a common command provider.
  ([#5](https://github.com/davep/textual-enhanced/pull/5))

## v0.1.0

**Released: 2025-02-01**

- Initial release.

[//]: # (ChangeLog.md ends here)
